summaryrefslogtreecommitdiffstats
path: root/lib/compatibility/kmdi/qextmdi/kmdichildarea.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/compatibility/kmdi/qextmdi/kmdichildarea.h')
-rw-r--r--lib/compatibility/kmdi/qextmdi/kmdichildarea.h29
1 files changed, 15 insertions, 14 deletions
diff --git a/lib/compatibility/kmdi/qextmdi/kmdichildarea.h b/lib/compatibility/kmdi/qextmdi/kmdichildarea.h
index 4a074889..ef1495e7 100644
--- a/lib/compatibility/kmdi/qextmdi/kmdichildarea.h
+++ b/lib/compatibility/kmdi/qextmdi/kmdichildarea.h
@@ -6,8 +6,8 @@
// begin : 07/1999 by Szymon Stefanek as part of kvirc
// (an IRC application)
// changes : 09/1999 by Falk Brettschneider to create an
-// - 06/2000 stand-alone Qt extension set of
-// classes and a Qt-based library
+// - 06/2000 stand-alone TQt extension set of
+// classes and a TQt-based library
// 2000-2003 maintained by the KDevelop project
//
// copyright : (C) 1999-2003 by Falk Brettschneider
@@ -49,12 +49,13 @@ class KMdiChildAreaPrivate;
* and manages the frame widgets of attached MDI views.
* All actions and stuff concerning only to childframes are handled here.
*/
-class KMDI_EXPORT KMdiChildArea : public QFrame
+class KMDI_EXPORT KMdiChildArea : public TQFrame
{
friend class KMdiChildFrmCaption;
friend class KMdiChildFrm;
Q_OBJECT
+ TQ_OBJECT
// attributes
public:
@@ -101,7 +102,7 @@ public:
/**
* Consruction. Note: This class needn't to know about KMdiMainFrm .
*/
- KMdiChildArea( TQWidget *parent );
+ KMdiChildArea( TQWidget *tqparent );
/**
* Destructor : THERE should be no child windows anymore...
@@ -137,13 +138,13 @@ public:
void setTopChild( KMdiChildFrm* child, bool setFocus = false );
/**
- * Returns the topmost child (the active one) or 0 if there are no children.
+ * Returns the topmost child (the active one) or 0 if there are no tqchildren.
* Note that the topmost child may be also hidded , if ALL the windows are minimized.
*/
inline KMdiChildFrm * topChild() const { return m_pZ->last(); }
/**
- * Returns the number of visible children
+ * Returns the number of visible tqchildren
*/
int getVisibleChildCount() const;
@@ -156,31 +157,31 @@ public:
/**
* Sets the MDI childframe window caption font
- * A relayout does not occur when using this function
+ * A retqlayout does not occur when using this function
*/
void setMdiCaptionFont( const TQFont &fnt );
/**
* Sets the foreground color of the active MDI childframe window caption
- * A relayout does not occur when using this function
+ * A retqlayout does not occur when using this function
*/
void setMdiCaptionActiveForeColor( const TQColor &clr );
/**
* Sets the background color of the active MDI childframe window captions
- * A relayout does not occur when using this function
+ * A retqlayout does not occur when using this function
*/
void setMdiCaptionActiveBackColor( const TQColor &clr );
/**
* Sets the foreground color of inactive MDI childframe window captions
- * A relayout does not occur when using this function
+ * A retqlayout does not occur when using this function
*/
void setMdiCaptionInactiveForeColor( const TQColor &clr );
/**
* Sets the background color of inactive MDI childframe window captions
- * A relayout does not occur when using this function
+ * A retqlayout does not occur when using this function
*/
void setMdiCaptionInactiveBackColor( const TQColor &clr );
@@ -239,9 +240,9 @@ public slots:
void tileVertically();
/**
* Position and layout the minimized child frames
*/
- void layoutMinimizedChildren();
+ void tqlayoutMinimizedChildren();
protected:
@@ -251,7 +252,7 @@ protected:
void tileAllInternal( int maxWnds );
/**
- * Automatically resizes a maximized MDI view and layouts the positions of minimized MDI views.
+ * Automatically resizes a maximized MDI view and tqlayouts the positions of minimized MDI views.
*/
virtual void resizeEvent( TQResizeEvent * );
@@ -239,9 +240,9 @@ public slots:
void tileVertically();
/**
- * Position and layout the minimized child frames
+ * Position and tqlayout the minimized child frames
*/